@@ -20,7 +20,7 @@
 
 package App::MtAws::GlacierRequest;
 
-our $VERSION = '1.115';
+our $VERSION = '1.116';
 
 use strict;
 use warnings;
@@ -519,9 +519,14 @@ sub perform_lwp
 		my $dt = time()-$t0;
 
 		if (($resp->code eq '500') && $resp->header('Client-Warning') && ($resp->header('Client-Warning') eq 'Internal response')) {
-			print "PID $$ HTTP connection problem (timeout?). Will retry ($dt seconds spent for request)\n";
-			$self->{last_retry_reason} = 'Internal response';
-			throttle($i);
+			if ($resp->content =~ /Can't verify SSL peers without knowing which Certificate Authorities to trust/i) {
+				die exception 'lwp_ssl_ca_exception' =>
+					'Can\'t verify SSL peers without knowing which Certificate Authorities to trust. Probably "Mozilla::CA" module is missing';
+			} else {
+				print "PID $$ HTTP connection problem (timeout?). Will retry ($dt seconds spent for request)\n";
+				$self->{last_retry_reason} = 'Internal response';
+				throttle($i);
+			}
 		} elsif ($resp->code =~ /^(500|408)$/) {
 			print "PID $$ HTTP ".$resp->code." This might be normal. Will retry ($dt seconds spent for request)\n";
 			$self->{last_retry_reason} = $resp->code;
